======================
Django MongoDB Backend
======================

version 6.0.x for Django 6.0.x

.. rubric:: Everything you need to know about Django MongoDB Backend.

First steps
===========

**Getting started:**

- :doc:`Installation <intro/install>`
- :doc:`Configuring a project <intro/configure>`
- :doc:`howto/contrib-apps`
- :doc:`topics/known-issues`

Getting help
============

Having trouble? We’d like to help!

- Try the :doc:`faq` – it’s got answers to many common questions.

- Looking for specific information? Try the :ref:`genindex`, :ref:`modindex`,
  or the detailed :doc:`table of contents <contents>`.

- The :doc:`howto/index` section has step-by-step guides for common tasks.

- Didn't find an answer? You're welcome to ask questions on our `support
  channels <https://www.mongodb.com/docs/manual/support/>`_.

- Report bugs and request features in our :ref:`issue tracker <issue-tracker>`.

Models
======

**Reference material:**

- :doc:`ref/models/fields`
- :doc:`ref/models/querysets`
- :doc:`ref/models/models`
- :doc:`ref/models/indexes`
- :doc:`ref/models/constraints`
- :doc:`ref/models/search`
- :doc:`ref/database`
- :doc:`ref/contrib/gis`
- :doc:`ref/django-admin`

**Topic guides:**

- :doc:`topics/embedded-models`
- :doc:`topics/transactions`
- :doc:`topics/urls`

Forms
=====

- :doc:`ref/forms`

MongoDB Features
================

- **Queryable Encryption:**
  :doc:`How-to guide </howto/queryable-encryption>` |
  :doc:`/ref/models/encrypted-fields/`
- **Settings:**
  :doc:`Django MongoDB Backend-specific settings </ref/settings>`
- **System checks:**
  :doc:`Reference list <ref/checks>`

Miscellaneous
=============

- :doc:`releases/index`
- :doc:`internals/index`

.. Keep this toctree in sync with contents.rst.

.. toctree::
    :hidden:
    :maxdepth: 2

    intro/index
    topics/index
    ref/index
    howto/index
    faq
    releases/index
    internals/index
